function [word] = predict_word(a,alpha,observations,wordlist)

    % N.B. - wordlist MUST contain only words with 5 or more letters

    MAX_TO_DISPLAY = 10;
    
    T = length(observations);
    R = size(wordlist,1);
    word_probs = ones(R,1);

    % look at observations up to t (forward algorithm only)
    for t=1:T
        letters = wordlist(:,t);
        for k=1:R
            i = char2number(letters(k));
            word_probs(k) = word_probs(k) * alpha(t,i) / sum(alpha(t,:));
        end
    end

    % after we run out of observations, just look at transition probs
    for t=T+1:5
        if(t == 1) % in case T = 0, i.e., no observations
            letters = wordlist(:,t);
            for k=1:R
                i = char2number(letters(k));
                word_probs(k) = word_probs(k) * alpha(1,i); % the prior
            end
            continue;
        end
        old_letters = letters;
        letters = wordlist(:,t);
        for k=1:R
            i = char2number(old_letters(k));
            j = char2number(letters(k));
            if(word_probs(k) > 0)
                word_probs(k) = word_probs(k) * a(i,j);
            end
        end
    end

    % sort nonzero word probabilities, display all possibilities, predict
    % most probable word
    disp('Possibilities:');
    possibilities = find(word_probs > 0); % so it can sort much faster
    [sorted_probs,ranks] = sort(word_probs(possibilities), 1, 'descend');
    sorted_probs = sorted_probs(1:min(MAX_TO_DISPLAY, length(possibilities)));
    word = wordlist(possibilities(ranks(1)),:);
    for i=1:length(sorted_probs)
       disp(sprintf('%d %s', sorted_probs(i), wordlist(possibilities(ranks(i)),:))); 
    end
